function [data, auxData, metaData, txtData, weights] = mydata_Bufo_bufo

%% set metaData
metaData.phylum     = 'Chordata'; 
metaData.class      = 'Amphibia'; 
metaData.order      = 'Anura'; 
metaData.family     = 'Bufonidae';
metaData.species    = 'Bufo_bufo'; 
metaData.species_en = 'Common toad'; 
metaData.T_typical  = C2K(15); % K, body temp
metaData.data_0     = {'ab'; 'aj'; 'ap'; 'am'; 'Lb'; 'Lj'; 'Lp'; 'Li'; 'Wwb'; 'Wwj'; 'Wwp'; 'Wwi'; 'Ri'}; 
metaData.data_1     = {'t-L'; 'pX-pG'}; 

metaData.COMPLETE = 2.6; % using criteria of LikaKear2011

metaData.author   = {'Jan Baas';'Bas Kooijman'};    
metaData.date_subm = [2014 05 31];              
metaData.email    = {'janbaa@ceh.ac.uk'};            
metaData.address  = {'VU University, Amsterdam'};   

metaData.author_mod_1   = {'Bas Kooijman'};    
metaData.date_mod_1 = [2017 10 24];              
metaData.email_mod_1    = {'bas.kooijman@vu.nl'};            
metaData.address_mod_1  = {'VU University, Amsterdam'};   

metaData.curator     = {'Starrlight Augustine'};
metaData.email_cur   = {'starrlight@akvaplan.niva.no'}; 
metaData.date_acc    = [2017 10 24]; 


%% set data
% zero-variate data

data.ab = 10;    units.ab = 'd';    label.ab = 'age at birth';             bibkey.ab = 'guessed';   
  temp.ab = C2K(15);  units.temp.ab = 'K'; label.temp.ab = 'temperature';
data.tj = 58;    units.tj = 'd';    label.tj = 'time since birth at metam';bibkey.tj = 'KatzWari2003';   
  temp.tj = C2K(15);  units.temp.tj = 'K'; label.temp.tj = 'temperature';
data.tp = 2.5*365;  units.tp = 'd';    label.tp = 'time since metam at puberty'; bibkey.tp = 'EoL';
  temp.tp = C2K(15);  units.temp.tp = 'K'; label.temp.tp = 'temperature';
data.am = 13000; units.am = 'd';    label.am = 'life span';                bibkey.am = 'Wiki';   
  temp.am = C2K(15);  units.temp.am = 'K'; label.temp.am = 'temperature'; 

data.Lb  = 0.3;  units.Lb  = 'cm';  label.Lb  = 'total length at birth';   bibkey.Lb  = 'KatzWari2003';  
data.Lj  = 1.3;  units.Lj  = 'cm';  label.Lj  = 'total length at metam';   bibkey.Lj  = 'KatzWari2003'; 
data.Lp  = 13;   units.Lp  = 'cm';  label.Lp  = 'total length at puberty'; bibkey.Lp  = 'KatzWari2003'; 
data.Li  = 15;   units.Li  = 'cm';  label.Li  = 'ultimate total length';   bibkey.Li  = 'KatzWari2003';

data.Wwb = 0.07; units.Wwb = 'g';   label.Wwb = 'wet weight at birth';     bibkey.Wwb = 'BrunBern2009';
data.Wwj = 0.35; units.Wwj = 'g';   label.Wwj = 'wet weight at metam';     bibkey.Wwj = 'KatzWari2003';
data.Wwp = 60;   units.Wwp = 'g';   label.Wwp = 'wet weight at puberty';   bibkey.Wwp = 'KatzWari2003';
data.Wwi = 80;   units.Wwi = 'g';   label.Wwi = 'ultimate wet weight';     bibkey.Wwi = 'Wiki';

data.Ri  = 1500/365;   units.Ri  = '#/d'; label.Ri  = 'maximum reprod rate';     bibkey.Ri  = 'EoL';   
temp.Ri = C2K(15);  units.temp.Ri = 'K'; label.temp.Ri = 'temperature';
comment.Ri = '1 brood/year';
 
% uni-variate data
% KatzWari2003: time since birth (d) at 15 C
% largest body mass of tadpoles: 0.35 g
data.tL = [ ... % time since hatch (day 1 = hatching day), body length (mm)
16.796	3.036
16.796	3.993
24.102	4.949
23.932	6.065
23.932	6.862
30.898	8.855
30.898	9.891
30.898	11.087
38.034	9.891
38.034	10.848
37.694	11.884
44.320	10.928
44.320	11.725
44.320	12.841
50.947	9.971
50.947	11.007
50.947	11.964
50.947	13.000
58.083	11.007
58.083	12.043
58.083	13.000];
data.tL(:,1) = data.tL(:,1) - 1; % set hatch at zero
data.tL(:,2) = data.tL(:,2)/10; % convert mm to cm
units.tL   = {'d', 'cm'};  label.tL = {'time since hatch', 'total length'};  
temp.tL    = C2K(15);  units.temp.tL = 'K'; label.temp.tL = 'temperature';
bibkey.tL = 'KatzWari2003';
  
% pX-pG data from Jorg1988 at 21C
% toads weigh 19 pm 5.9 g (sd).
% units are strange due to lack of time
data.pXpG = [ ... % ingestion (kJ/d.g), growth (kJ/d.g)
18.308	8.123
20.495	12.796
21.867	14.507
21.623	12.001
23.782	12.803
25.497	14.856
28.566	16.001
28.574	17.140
31.534	18.968
32.433	17.831
32.779	18.629
33.130	20.224
39.730	23.654
43.940	25.940
50.547	30.395];
data.pXpG = 19 * data.pXpG; % convert kJ/d.g to kJ/d
units.pXpG = {'kJ/d', 'kJ/d'}; label.pXpG = {'ingestion', 'growth'};  
temp.pXpG  = C2K(21);  units.temp.pXpG = 'K'; label.temp.pXpG = 'temperature';
bibkey.pXpG = 'Jorg1988';

%% set weights for all real data
weights = setweights(data, []);
weights.pXpG = 0 * weights.pXpG;

%% set pseudodata and respective weights
[data, units, label, weights] = addpseudodata(data, units, label, weights);

%% pack auxData and txtData for output
auxData.temp = temp;
txtData.units = units;
txtData.label = label;
txtData.bibkey = bibkey;
txtData.comment = comment;

% Discussion points
D1 = 'We here assume that, at metam, del_M and z change';
D2 = 'Jorg1988 data got weight 0 because the time unit was not indicated and toad weight unclear';
metaData.discussion = struct('D1', D1, 'D2', D2);

%% Facts
F1 = ['Spends its life as a tadpole in the water and as an adult mainly on land in water rich environments. '...
      'Female toads are somewhat larger (~15 cm) than males (~13 cm). '...
      'It has a larval period of ca 58 days and it can become relatively old with a max age of ca 36 years. '... 
      'At an age of 3 - 4 years it starts reproduction. It lays a max of 8,000 eggs once a year. '...
      'During winter it hibernates and in spring massive amounts of toads can migrate to their breeding grounds. '... 
      'It has a characteristic way of laying eggs in strings.'];
metaData.bibkey.F1 = 'Wiki'; 
F2 = 'Tadpoles lose much of their weight during metamorphosis';
metaData.bibkey.F2 = 'KatzWari2003'; 
metaData.facts = struct('F1',F1,'F2',F2);

%% References
bibkey = 'Wiki'; type = 'Misc'; bib = ...
'howpublished = {\url{http://en.wikipedia.org/wiki/Bufo_bufo}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Kooy2010'; type = 'Book'; bib = [ ...  % used in setting of chemical parameters and pseudodata
'author = {Kooijman, S.A.L.M.}, ' ...
'year = {2010}, ' ...
'title  = {Dynamic Energy Budget theory for metabolic organisation}, ' ...
'publisher = {Cambridge Univ. Press, Cambridge}, ' ...
'pages = {Table 4.2 (page 150), 8.1 (page 300)}, ' ...
'howpublished = {\url{http://www.bio.vu.nl/thb/research/bib/Kooy2010.html}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'KatzWari2003'; type = 'Article'; bib = [ ... 
'author = {Katzmann, S. and Waringer-Loschenkohl, A. and Waringer, A.}, ' ... 
'year = {2003}, ' ...
'title = {Effects of inter- and intraspecific competition on growth and development of Bufo viridis and \emph{Bufo bufo} tadpoles}, ' ...
'journal = {Limnologica}, ' ...
'volume = {33}, ' ...
'pages = {122--130}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Jorg1988'; type = 'Article'; bib = [ ... 
'author = {Jorgensen, C. J.}, ' ... 
'year = {1988}, ' ...
'title = {Metabolic costs of growth and maintenance in the toad, \emph{Bufo bufo}}, ' ...
'journal = {J. exp Biol.}, ' ...
'volume = {138}, ' ...
'pages = {319--331}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'BrunBern2009'; type = 'Article'; bib = [ ... 
'author = {E. Brunelli and I. Bernab\`{o} and C. Bergb and K. Lundstedt-Enkel and A. Bonaccia and S. Tripepia}, ' ... 
'year = {2009}, ' ...
'title = {Environmentally relevant concentrations of endosulfan impair development, metamorphosis and behaviour in \emph{Bufo bufo} tadpoles}, ' ...
'journal = {Aquatic Toxicology}, ' ...
'volume = {91}, ' ...
'pages = {135--142}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'EoL'; type = 'Misc'; bib = ...
'howpublished = {\url{http://eol.org/pages/333310/overview}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
